{% extends "stg_detail.html" %}

{% block details %}
<h1><a href="{{ obj.get_absolute_url }}">File {{ obj.pk }}: {{ obj.filename }}</a></h1>

<h2>Attributes</h2>

<ul>
    <li>File Type: {{ obj.file_type }}</li>
    <li>State: {{ obj.state.abbreviation }}</li>
    <li>Year: {{ obj.year }}</li>
    <li>Quarter: {{ obj.quarter }}</li>
    <li>Filename: {{ obj.filename }}</li>
    <li>Full Path: {{ obj.full_path }}</li>
    <li>Size on Disk: {{ obj.size_on_disk }}</li>
    <li>Loadfile: {{ obj.loadfile }}</li>
</ul>

<h2>Derived Properties</h2>

<ul>
    <li>Human-Readable Size: {{ obj.hr_size }} MiB</li>
    <li>Estimated Rows: {{ obj.est_rows }}</li>
{% endblock %}
